Python Cardano module
=====================

This software is in early development phase. Please consider it experimental and don't rely on any
API to be stable in the future. Once first building blocks mature, I'll cover them with unit tests
and documentation.

There's no official release yet.

This module is the implementation of `the idea`_ submitted to Catalyst Project.

.. _`the idea`: https://cardano.ideascale.com/a/dtd/Python-module/333770-48088

Donate
------

If you like to support the idea with a donation, the address is::

    addr1qy5xfmuxy22h9c82h2fc96du769cyqptn45h9xhqkjwuh07y42xxcwu506y3czyjp00f66r9t2u5nrrunyu867f2fcmskzkcmp

.. image:: donate.qr.png

Thank you.
